Index: runtime/vm/handles_impl.h |
diff --git a/runtime/vm/handles_impl.h b/runtime/vm/handles_impl.h |
index 370b34e440d7dee6a03f6097477a67599f4ed1bd..ad005bb8d60172df8a37a390fbdf73bf7c9dc288 100644 |
--- a/runtime/vm/handles_impl.h |
+++ b/runtime/vm/handles_impl.h |
@@ -123,18 +123,18 @@ uword Handles<kHandleSizeInWords, |
} |
// Figure out the current zone using the current Isolate and |
// check if the specified handle has been allocated in this zone. |
template <int kHandleSizeInWords, int kHandlesPerChunk, int kOffsetOfRawPtr> |
bool Handles<kHandleSizeInWords, |
kHandlesPerChunk, |
kOffsetOfRawPtr>::IsZoneHandle(uword handle) { |
// TODO(5411412): Accessing the current isolate is a performance problem, |
// consider passing it down as a parameter. |
- Isolate* isolate = Isolate::Current(); |
- ASSERT(isolate != NULL); |
- ASSERT(isolate->current_zone() != NULL); |
- Handles* handles = isolate->current_zone()->handles(); |
+ Thread* thread = Thread::Current(); |
+ ASSERT(thread != NULL); |
+ ASSERT(thread->zone() != NULL); |
+ Handles* handles = thread->zone()->handles(); |
ASSERT(handles != NULL); |
return handles->IsValidZoneHandle(handle); |
} |
@@ -123,18 +123,18 @@ uword Handles<kHandleSizeInWords, |
} |
-// Figure out the current zone using the current Isolate and |
+// Figure out the current zone using the current Thread and |
// check if the specified handle has been allocated in this zone. |
template <int kHandleSizeInWords, int kHandlesPerChunk, int kOffsetOfRawPtr> |
@@ -123,18 +123,18 @@ uword Handles<kHandleSizeInWords, |
kHandlesPerChunk, |
kOffsetOfRawPtr>::IsZoneHandle(uword handle) { |
- // TODO(5411412): Accessing the current isolate is a performance problem, |
+ // TODO(5411412): Accessing the current thread is a performance problem, |
// consider passing it down as a parameter. |